package cn.com.qmth.examcloud.task.service.job;

import cn.com.qmth.examcloud.core.oe.student.api.OeStudentExamRecordCloudService;
import cn.com.qmth.examcloud.core.oe.student.api.bean.ExamingRecordBean;
import cn.com.qmth.examcloud.core.oe.student.api.request.CleanExamingRecordReq;
import cn.com.qmth.examcloud.core.oe.student.api.request.GetExamingRecordReq;
import cn.com.qmth.examcloud.core.oe.student.api.response.GetExamingRecordResp;
import cn.com.qmth.examcloud.web.bootstrap.PropertyHolder;
import cn.com.qmth.examcloud.web.task.AbstractTask;
import cn.com.qmth.examcloud.web.task.ScheduleJob;
import cn.com.qmth.examcloud.web.task.TaskTracker;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * 网考自动交卷服务
 */
@Component("oeCleanExamingRecordTask")
public class OeCleanExamingRecordTask extends AbstractTask {

	@Autowired
	TaskTracker taskTracker;
	
	@Autowired
	private OeStudentExamRecordCloudService oeStudentExamRecordCloudService;
	private static final Log log = LogFactory.getLog(OeCleanExamingRecordTask.class);
	
	@Override
	public void run(ScheduleJob scheduleJob) throws Exception {
		Long startId = 0L;
		int limit = PropertyHolder.getInt("oe.cleanExamingRecord.limit", 100);

		while (true) {
			GetExamingRecordReq req = new GetExamingRecordReq();
			req.setLimit(limit);
			req.setStartId(startId);
			GetExamingRecordResp resp = oeStudentExamRecordCloudService.getExamingRecords(req);

			if (startId.equals(resp.getNextId())) {
				break;
			} else {
				//因为有可能手动交卷处理掉，所以找不到数据时，不抛错，继续执行下一批数据
				if (null == resp.getList() || resp.getList().isEmpty()) {
					startId = resp.getNextId();
					continue;
				}

				for (ExamingRecordBean examingRecord : resp.getList()) {
					try {
						CleanExamingRecordReq cleanExamingRecordReq = new CleanExamingRecordReq();
						cleanExamingRecordReq.setExamRecordDataId(examingRecord.getExamRecordDataId());
						cleanExamingRecordReq.setId(examingRecord.getId());
						cleanExamingRecordReq.setStudentId(examingRecord.getStudentId());
						oeStudentExamRecordCloudService.cleanExamingRecord(cleanExamingRecordReq);
					} catch (Exception e) {
						log.error("[oeCleanExamingRecordTask_"+examingRecord.getExamRecordDataId()+"]交卷自动服务处理失败",e);
					}
				}
				startId = resp.getNextId();
			}
		}
	}

	@Override
	public TaskTracker getTaskTracker() {
		return taskTracker;
	}
}
